@@ -46,8 +46,6 @@ class Neuron:
         """
 
         import matplotlib as mpl
-
-        # mpl.use("Agg")
         import matplotlib.pyplot as plt
 
         if not ax and not fig:
@@ -57,11 +55,26 @@ class Neuron:
 
         for layer in self.soma_layers.values():
             if axis == "z":
-                ax.plot([i.x for i in layer], [i.y for i in layer], color=color, linewidth=linewidth)
+                ax.plot(
+                    [i.x for i in layer],
+                    [i.y for i in layer],
+                    color=color,
+                    linewidth=linewidth,
+                )
             elif axis == "x":
-                ax.plot([i.y for i in layer], [i.z for i in layer], color=color, linewidth=linewidth)
+                ax.plot(
+                    [i.y for i in layer],
+                    [i.z for i in layer],
+                    color=color,
+                    linewidth=linewidth,
+                )
             elif axis == "y":
-                ax.plot([i.x for i in layer], [i.z for i in layer], color=color, linewidth=linewidth)
+                ax.plot(
+                    [i.x for i in layer],
+                    [i.z for i in layer],
+                    color=color,
+                    linewidth=linewidth,
+                )
 
         for branch in self.branches:
             branch.plot(ax=ax, fig=fig, axis=axis, color=color, linewidth=linewidth)
@@ -159,82 +172,40 @@ class Neuron:
         """
         return self.total_bif_nodes()
 
+    def total_dim(self, dim, percentile=None):
+        """
+        :param dim: `str` describing what dim to perform the analysis on
+        :returns: the span of all coordinates in the direction `dim`
+        :rtype `numeric`, inherited from coordinates:
+        """
+        vals = [getattr(x,dim) for x in self.iter_all_points()]
+        if percentile is None:
+            return max(vals)-min(vals)
+        else:
+            percentile = (100 - percentile)/2 # 2.5
+            minmax = np.percentile(vals, [percentile, 100-percentile])
+            return minmax[1] - minmax[0]
+
     def total_width(self, percentile=None):
         """
         :returns: The width of the smallest bounding box required to encapsulate this :class:`Neuron`
         :rtype: `numeric`, inherited from :attr:`x`
         """
-        min_x, max_x = None, None
-        for z, layer in self.soma_layers.items():
-            for pt in layer:
-                if min_x is None:
-                    min_x = pt.x
-                    max_x = pt.x
-                else:
-                    min_x = min(pt.x, min_x)
-                    max_x = max(pt.x, max_x)
-        for branch in self.branches:
-            q = deque([branch])
-            while q:
-                i = q.pop()
-                if min_x is None:  # needed in case no soma points
-                    min_x = i.x
-                    max_x = i.x
-                min_x = min(i.x, min_x)
-                max_x = max(i.x, max_x)
-                q.extend(iter(i))
-        return max_x - min_x
+        return self.total_dim('x', percentile=percentile)
 
-    def total_height(self):
+    def total_height(self, percentile=None):
         """
         :returns: The height of the smallest bounding box required to encapsulate this :class:`Neuron`
         :rtype: `numeric`, inherited from :attr:`y`
         """
-        min_y, max_y = None, None
-        for z, layer in self.soma_layers.items():
-            for pt in layer:
-                if min_y is None:
-                    min_y = pt.y
-                    max_y = pt.y
-                else:
-                    min_y = min(pt.y, min_y)
-                    max_y = max(pt.y, max_y)
-        for branch in self.branches:
-            q = deque([branch])
-            while q:
-                i = q.pop()
-                if min_y is None:  # needed in case no soma points
-                    min_y = i.x
-                    max_y = i.x
-                min_y = min(i.y, min_y)
-                max_y = max(i.y, max_y)
-                q.extend(iter(i))
-        return max_y - min_y
+        return self.total_dim('y', percentile=percentile)
 
-    def total_depth(self):
+    def total_depth(self, percentile=None):
         """
         :returns: The depth of the smallest bounding box required to encapsulate this :class:`Neuron`
         :rtype: `numeric`, inherited from :attr:`z`
         """
-        min_z, max_z = None, None
-        for z, layer in self.soma_layers.items():
-            if min_z is None:
-                min_z = z
-                max_z = z
-            else:
-                min_z = min(z, min_z)
-                max_z = max(z, max_z)
-        for branch in self.branches:
-            q = deque([branch])
-            while q:
-                i = q.pop()
-                if min_z is None:  # needed in case no soma points
-                    min_z = i.x
-                    max_z = i.x
-                min_z = min(i.z, min_z)
-                max_z = max(i.z, max_z)
-                q.extend(iter(i))
-        return max_z - min_z
+        return self.total_dim('z',percentile=percentile)
 
     def slice_surface_areas(self):
         """
@@ -261,6 +232,15 @@ class Neuron:
         :note: This may yield low accuracy if there are few Z-slices traced
         :rtype: `dict` mapping z-values to `float`
         """
+        if len(self.soma_layers) == 0:
+            return 0
+        elif len(self.soma_layers) == 1:
+            out = 0.0
+            for layer in self.soma_layers.values():
+                for pt in layer:
+                    out += (4/3) * math.pi * (pt.r**3.0)
+            return out
+
         ssa = self.slice_surface_areas()
         total, z_height = 0.0, 0.0
 
@@ -290,14 +270,20 @@ class Neuron:
         :note: This may yield low accuracy if there are few Z-slices traced or if the tracing is incomplete
         :rtype: `float`
         """
+        if len(self.soma_layers) == 0:
+            return 0
+        elif len(self.soma_layers) == 1:
+            out = 0.0
+            for layer in self.soma_layers.values():
+                for pt in layer:
+                    out += 4 * math.pi * (pt.r**2.0)
+            return out
+
         sp = self.slice_perimeters()
         ssa = self.slice_surface_areas()
         total, z_height = 0.0, 0.0
 
         z_indices = list(sorted(sp.keys()))
-        if len(z_indices) <= 1:
-            raise ValueError("Can not calculate volume of 1-slice soma")
-
         for i, z in enumerate(z_indices):
             if i == 0 or i == len(z_indices) - 1:  # first or last iteration
                 total += ssa[z]  # top/bottom area
@@ -373,19 +359,30 @@ class Neuron:
                 out = max(out, node.branching_order())
         return out
 
-    def get_main_branch(self):
+    def get_main_branch(self, strahler=True):
         """
         :returns: The longest branch from the :class:`Neuron`
         :note: Returns `None` if there are no branches in this :class:`Neuron`
+        :param strahler: Default `True`. Determines if a strahler-order mechanism should be used to determine main branch
         :rtype: `int`
         """
-        out, m = None, 0
+        out, m = None, 0 
         for branch in self.branches:
-            if branch.total_child_nodes() > m:
-                m = branch.total_child_nodes()
+            met = branch.total_tip_nodes() if strahler else branch.total_child_nodes()
+            if met > m:
+                m = met
                 out = branch
         return out
 
+    def all_branch_points(self):
+        """
+        :returns: 
+        """
+        out = []
+        for branch in self.branches:
+            out.extend(branch.get_bifurcation_nodes())
+        return out
+
     def all_segment_lengths(self):
         """Creates sorted list of all segment lengths in a neuron`
 
@@ -486,7 +483,7 @@ class Neuron:
         out = self.all_path_angles()
         return max(out)
 
-    def all_branch_angles(n):
+    def all_branch_angles(self):
         """Creates a list with angles of all the branch points in a neuron in degrees between [0, 180]
 
         :param n: starting point for gathering branch point angles
@@ -500,7 +497,7 @@ class Neuron:
             >>> neuron.all_branch_angles()
             [90.8386644299175, 83.62062979155719, 83.62062979155719, 109.47122063449069]
         """
-        q = get_branch_points(self)
+        q = self.all_branch_points()
         out = []
         while q:
             i = q.pop()
@@ -543,7 +540,7 @@ class Neuron:
         out = self.all_branch_angles()
         return sum(out) / len(out)
 
-    def max_branch_angle(n):
+    def max_branch_angle(self):
         """Determines the maximal branch point angle in degrees between [0, 180]
 
         :returns: maximal branch angle
@@ -572,6 +569,13 @@ class Neuron:
     # def colless_index(self):
     #    return self.get_main_branch().colless_index()
 
+    def max_segment_length(self):
+        out = 0.0
+        for branch in self.branches:
+            for a, b in branch.get_all_segments():
+                out = max(a.path_dist_to_child(b), out)
+        return out
+
     def arbor_dist(self):
         """
         :returns: The distance from the :func:`soma_centroid` to the positional average of all :attr:`branch` :class:`TracingPoints`
@@ -629,8 +633,6 @@ class Neuron:
         :returns: Nothing
         :rtype: `None`
         """
-        import numpy as np
-
         rot = rotation_matrix(z, y, x)
         for pt in self.iter_all_points():
             coords = rot.dot(np.array([pt.x, pt.y, pt.z]))
@@ -716,14 +718,17 @@ class Neuron:
 
         Example:
             >>> neuron = from_swc("Example1.swc")
-            >>> all_neurites_tortuosities(neuron)
+            >>> neuron.all_neurites_tortuosities()
             [0.04134791479135339,
              0.05300604176745361,
              0.14956195330433844,
              0.15049238421642142,
              0.18919849587081047]
         """
-        return sorted([i.neurite_tortuosity() for i in self.get_tip_nodes()])
+        all_tip_nodes = []
+        for branch in self.branches:
+            all_tip_nodes.extend(branch.get_tip_nodes())
+        return sorted([i.neurite_tortuosity() for i in all_tip_nodes])
 
     def max_tortuosity(self):
         """Determines the 99.5 percentile of log(tortuosity) across all neurites in a neuron
@@ -734,7 +739,7 @@ class Neuron:
 
         Example:
             >>> neuron = from_swc("Example1.swc")
-            >>> max_tortuosity(neuron)
+            >>> neuron.max_tortuosity(neuron)
             0.1884243736377227
         """
         return np.percentile(self.all_neurites_tortuosities(), 99.5)
@@ -747,7 +752,7 @@ class Neuron:
 
         Example:
             >>> neuron = from_swc("Example1.swc")
-            >>> median_tortuosity(neuron)
+            >>> neuron.median_tortuosity(neuron)
             0.14956195330433844
         """
         return statistics.median(self.all_neurites_tortuosities())
@@ -783,9 +788,29 @@ class Neuron:
             >>> neuron.branch_order_counts()
             [0, 0, 4]
         """
-        out = Counter([x.branching_order() for x in self.get_branch_points()])
+
+        out = Counter([x.branching_order() for x in self.all_branch_points()])
         return [out[i] for i in range(max(out.keys()) + 1)]
 
+    def branch_order_histogram(self, bins=20):
+        """Creates a histogram (an array of counts and an array of edges) of all
+           branch orders with a default of 20 bins between [0, 180] degrees
+
+        :param bins: number of bins for histogram to have
+        :type bins: `int`
+
+        :returns: histogram of all branch orders
+        :rtype: `tuple` two `numpy.array`, one with counts and one with edge values
+
+        Example:
+            >>> neuron = from_swc("Example1.swc")
+            >>> neuron.branch_order_histogram()
+            (array([0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 2, 0, 1, 0, 0, 0, 1, 1]),
+             array([  0.,   9.,  18.,  27.,  36.,  45.,  54.,  63.,  72.,  81.,  90.,
+                    99., 108., 117., 126., 135., 144., 153., 162., 171., 180.]))
+        """
+        return np.histogram(self.all_branch_orders(), bins=bins, range=(0, 180))
+
     def path_angles_histogram(self, bins=20):
         """Creates a histogram (an array of counts and an array of edges) of all path angles with
            default of 20 bins between [0, 180] degrees
@@ -895,112 +920,115 @@ class Neuron:
 
         Example:
             >>> neuron = from_swc("Example1.swc")
-            >>> neuron.euclidean_distances_to_soma()
+            >>> neuron.euclidean_distances_to_soma_histogram()
             (array([0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 0, 0, 1, 1]),
              array([0.   , 0.225, 0.45 , 0.675, 0.9  , 1.125, 1.35 , 1.575, 1.8  ,
                     2.025, 2.25 , 2.475, 2.7  , 2.925, 3.15 , 3.375, 3.6  , 3.825,
                     4.05 , 4.275, 4.5  ]))
         """
         out = [
-            i.euclidean_distances_to_soma()
-            for i in self.iter_all_points(exclude_soma=True)
+            i.euclidean_dist_to_root() for i in self.iter_all_points(exclude_soma=True)
         ]
         return np.histogram(out, bins=bins, range=(0, out[-1]))
 
-    def sholl_intersection(self, steps=36, proj="xy"):
-        """Creates a numpy array for the Sholl Intersection, which is all intersections at
-           different radii a certain number of steps away from center of input
+    # def sholl_intersection(self, steps=36, proj="xy"):
+    #     """Creates a numpy array for the Sholl Intersection, which is all intersections at
+    #        different radii a certain number of steps away from center of input
 
-        :param steps: number of steps desired between center and maximal neurite point
-        :type steps: `int`
+    #     :param steps: number of steps desired between center and maximal neurite point
+    #     :type steps: `int`
 
-        :param proj: which plane circle is located on
-        :type: `string`
+    #     :param proj: which plane circle is located on
+    #     :type: `string`
 
-        :returns: `numpy.array` consisting of `tuples` with radii position (`float`) and
-                  number of intersections (`int`)
-        :rtype: `numpy.ndarray`
+    #     :returns: `numpy.array` consisting of `tuples` with radii position (`float`) and
+    #               number of intersections (`int`)
+    #     :rtype: `numpy.ndarray`
 
-        Example:
-            >>> neuron = from_swc("Example1.swc")
-            >>> neuron.sholl_intersection()
-            array([[0.15713484, 1.        ],
-                   [0.31426968, 1.        ],
-                   [0.47140452, 1.        ],
-                   [0.62853936, 1.        ],
-                   [0.7856742 , 1.        ],
-                   [0.94280904, 1.        ],
-                   [1.09994388, 2.        ],
-                   [1.25707872, 2.        ],
-                   [1.41421356, 2.        ],
-                   [1.5713484 , 2.        ],
-                   [1.72848324, 2.        ],
-                   [1.88561808, 2.        ],
-                   [2.04275292, 2.        ],
-                   [2.19988776, 2.        ],
-                   [2.3570226 , 2.        ],
-                   [2.51415744, 2.        ],
-                   [2.67129228, 2.        ],
-                   [2.82842712, 3.        ],
-                   [2.98556197, 4.        ],
-                   [3.14269681, 4.        ],
-                   [3.29983165, 2.        ],
-                   [3.45696649, 2.        ],
-                   [3.61410133, 2.        ],
-                   [3.77123617, 2.        ],
-                   [3.92837101, 2.        ],
-                   [4.08550585, 2.        ],
-                   [4.24264069, 3.        ],
-                   [4.39977553, 2.        ],
-                   [4.55691037, 1.        ],
-                   [4.71404521, 1.        ],
-                   [4.87118005, 1.        ],
-                   [5.02831489, 1.        ],
-                   [5.18544973, 1.        ],
-                   [5.34258457, 1.        ],
-                   [5.49971941, 1.        ],
-                   [5.65685425, 1.        ]])
-        """
-        # determine center based on input
-        center = self.soma_centroid()
-        if proj == "xy":
-            center = Point(center[0], center[1])
-        elif proj == "yz":
-            center = Point(center[1], center[2])
-        elif proj == "xz":
-            center = Point(center[0], center[2])
-        raise AttributeError("proj must be either xy, yz, or xz")
+    #     Example:
+    #         >>> neuron = from_swc("Example1.swc")
+    #         >>> neuron.sholl_intersection()
+    #         array([[0.15713484, 1.        ],
+    #                [0.31426968, 1.        ],
+    #                [0.47140452, 1.        ],
+    #                [0.62853936, 1.        ],
+    #                [0.7856742 , 1.        ],
+    #                [0.94280904, 1.        ],
+    #                [1.09994388, 2.        ],
+    #                [1.25707872, 2.        ],
+    #                [1.41421356, 2.        ],
+    #                [1.5713484 , 2.        ],
+    #                [1.72848324, 2.        ],
+    #                [1.88561808, 2.        ],
+    #                [2.04275292, 2.        ],
+    #                [2.19988776, 2.        ],
+    #                [2.3570226 , 2.        ],
+    #                [2.51415744, 2.        ],
+    #                [2.67129228, 2.        ],
+    #                [2.82842712, 3.        ],
+    #                [2.98556197, 4.        ],
+    #                [3.14269681, 4.        ],
+    #                [3.29983165, 2.        ],
+    #                [3.45696649, 2.        ],
+    #                [3.61410133, 2.        ],
+    #                [3.77123617, 2.        ],
+    #                [3.92837101, 2.        ],
+    #                [4.08550585, 2.        ],
+    #                [4.24264069, 3.        ],
+    #                [4.39977553, 2.        ],
+    #                [4.55691037, 1.        ],
+    #                [4.71404521, 1.        ],
+    #                [4.87118005, 1.        ],
+    #                [5.02831489, 1.        ],
+    #                [5.18544973, 1.        ],
+    #                [5.34258457, 1.        ],
+    #                [5.49971941, 1.        ],
+    #                [5.65685425, 1.        ]])
+    #     """
+    #     # determine center based on input
+    #     center = self.soma_centroid()
+    #     if proj == "xy":
+    #         center = Point(center[0], center[1])
+    #     elif proj == "yz":
+    #         center = Point(center[1], center[2])
+    #     elif proj == "xz":
+    #         center = Point(center[0], center[2])
+    #     else:
+    #         raise AttributeError("proj must be either xy, yz, or xz")
 
-        # fills lines with all the segments in our neuron or tracing point
-        out = self.get_tip_nodes(a)
-        coord = []
-        while out:
-            i = out.pop()
-            if i.parent:
-                if proj == "xy":
-                    coord.append(((i.x, i.y), (i.parent.x, i.parent.y)))
-                elif proj == "yz":
-                    coord.append(((i.y, i.z), (i.parent.y, i.parent.z)))
-                else:
-                    coord.append(((i.x, i.z), (i.parent.x, i.parent.z)))
-                out.append(i.parent)
-        lines = MultiLineString(coord)
+    #     # fills lines with all the segments in our neuron or tracing point
+    #     out = deque()
+    #     for branch in self.branches:
+    #         out.extend(branch.get_tip_nodes())
 
-        # determines how many intersections occur at each location
-        maxPoint = Point(lines.bounds[2], lines.bounds[3])
-        line = LineString([center, maxPoint])
-        intersect = []
-        for i in range(1, steps + 1):
-            r = (line.length / steps) * i
-            c = center.buffer(r).boundary
-            i = c.intersection(lines)
-            if type(i) is Point:
-                intersect.append((r, 1))
-            elif type(i) is LineString:
-                intersect.append((r, 1))
-            else:
-                intersect.append((r, len(i)))
-        return np.array(intersect)
+    #     coord = []
+    #     while out:
+    #         i = out.pop()
+    #         if i.parent:
+    #             if proj == "xy":
+    #                 coord.append(((i.x, i.y), (i.parent.x, i.parent.y)))
+    #             elif proj == "yz":
+    #                 coord.append(((i.y, i.z), (i.parent.y, i.parent.z)))
+    #             else:
+    #                 coord.append(((i.x, i.z), (i.parent.x, i.parent.z)))
+    #             out.append(i.parent)
+    #     lines = MultiLineString(coord)
+
+    #     # determines how many intersections occur at each location
+    #     maxPoint = Point(lines.bounds[2], lines.bounds[3])
+    #     line = LineString([center, maxPoint])
+    #     intersect = []
+    #     for i in range(1, steps + 1):
+    #         r = (line.length / steps) * i
+    #         c = center.buffer(r).boundary
+    #         i = c.intersection(lines)
+    #         if type(i) is Point:
+    #             intersect.append((r, 1))
+    #         elif type(i) is LineString:
+    #             intersect.append((r, 1))
+    #         else:
+    #             intersect.append((r, len(i)))
+    #     return np.array(intersect)
 
     def all_branch_orders(self):
         """Creates a list with all the branch orders of all bifurcation points in neuron
@@ -1011,13 +1039,12 @@ class Neuron:
         Example:
             >>> neuron = from_swc("Example1.swc")
             >>> neuron.all_branch_orders()
-                [2, 2, 2, 2]
+                [3,3,2,1]
         """
-        q = self.get_branch_points()
+        q = self.all_branch_points()
         out = []
         while q:
-            i = q.pop()
-            out.append(len(i.children))
+            out.append(q.pop().branching_order())
         return out
 
     def branch_angles_x_branch_orders(self, bins=20):
@@ -1081,15 +1108,17 @@ class Neuron:
         orders = self.all_branch_orders()
         angles = self.all_branch_angles()
         return np.histogram2d(
-            orders, angles, bins=bins, range=[[0, ms.max_branch_order(n)], [0, 180]]
+            orders, angles, bins=bins, range=[[0, max(orders)], [0, 180]]
         )
 
-    def branch_angles_x_path_distances(self, bins=20):
+    def branch_angles_x_path_distances(self, bins=20, maxDist=None):
         """Creates a 2D histogram of branch angles as a function of path distances to the soma in
                 microns (across all branch points) with default bins of 20
 
         :param bins: number of bins for histogram to have
+        :param maxDist: maximum distance for the histogram, by default selects the maximum distance
         :type bins: `int`
+        :type maxDist: `float`
 
         :returns: 2D histogram of branch angles as a function of path distances
         :rtype: `tuple` of three `numpy.array`, respectively histogram, x edges, and y edges
@@ -1146,17 +1175,17 @@ class Neuron:
                      99., 108., 117., 126., 135., 144., 153., 162., 171., 180.]))
         """
         angles = self.all_branch_angles()
-        q = self.get_branch_points()
+        q = self.all_branch_points()
         dist = []
         while q:
             i = q.pop()
             length = 0
             while i.parent:
-                length += ms.euclidean_distance(i, i.parent)
+                length += i.euclidean_dist(i.parent)
                 i = i.parent
             dist.append(length)
         distSorted = sorted(dist)
-        maxDist = distSorted[-1]
+        maxDist = maxDist if (maxDist is not None) else distSorted[-1]
         return np.histogram2d(dist, angles, bins=bins, range=[[0, maxDist], [0, 180]])
 
     def path_angle_x_branch_order(self, bins=20):
@@ -1230,21 +1259,25 @@ class Neuron:
             i = p.pop()
             if i.children and len(i.children) > 1:
                 for j in range(len(i.children)):
-                    angles.append(ms.angle(i, i.parent, i.children[j]))
+                    angles.append(i.angle(i.parent, i.children[j]))
                     orders.append(len(i.children))
                     p.append(i.children[j])
             elif i.children:
-                angles.append(ms.angle(i, i.parent, i.children[0]))
+                angles.append(i.angle(i.parent, i.children[0]))
                 orders.append(len(i.children))
                 p.append(i.children[0])
-        return np.histogram2d( angles, orders, bins=bins, range=[[0, 180], [0, max(orders)]] )
+        return np.histogram2d(
+            angles, orders, bins=bins, range=[[0, 180], [0, max(orders)]]
+        )
 
-    def path_angle_x_path_distance(self, bins=20):
+    def path_angle_x_path_distance(self, bins=20, maxDist=None):
         """Creates a 2D histogram of path angles as a function of path distances to the soma in microns
            (across all nodes) with default bins of 20
 
         :param bins: number of bins for histogram to have
         :type bins: `int`
+        :param maxDist: maximum distance for the calculation of the histogram
+        :type maxDist: `float`
 
         :returns: 2D histogram of path angles as a function of path distances
         :rtype: `tuple` of three `numpy.array`, respectively histogram, x edges, and y edges
@@ -1302,18 +1335,21 @@ class Neuron:
              array([  0.,   9.,  18.,  27.,  36.,  45.,  54.,  63.,  72.,  81.,  90.,
                      99., 108., 117., 126., 135., 144., 153., 162., 171., 180.]))
         """
-        q = deque(self)
-        p = deque()
         angles = []
-        dist = []
-        maxLen = 0
-        while q:
-            it = q.pop()
-            p.extend(it)
-        while p:
-            i = p.pop()
-            path_angle_x_path_dist_helper(i, angles, dist)
-        return np.histogram2d(dist, angles, bins=bins, range=[[0, max(sortDist)], [0, 180]])
+        path_dists = []
+
+        for branch in self.branches:
+            for tp in branch.get_all_nodes():
+                if tp.is_tip() or tp.is_root():
+                    continue
+                pdtr = tp.path_dist_to_root()
+                for child in tp.children:
+                    angles.append(tp.angle(child, tp.parent))
+                    path_dists.append(pdtr)
+        maxDist = maxDist if (maxDist is not None) else max(path_dists)
+        return np.histogram2d(
+            path_dists, angles, bins=bins, range=[[0, maxDist], [0, 180]]
+        )
 
     def thickness_x_branch_order(self, bins=20):
         """Creates 2D histogram of neurite radii as a function of branch orders (across all nodes)
@@ -1386,7 +1422,9 @@ class Neuron:
                 orders.append(1)
             if i.children:
                 q.extend(i)
-        return np.histogram2d(orders, radii, bins=bins, range=[[0, maxOrder], [0, maxRad]])
+        return np.histogram2d(
+            orders, radii, bins=bins, range=[[0, maxOrder], [0, maxRad]]
+        )
 
     def thickness_x_path_distance(self, bins=20):
         """Creates 2D histogram of neurite radii as a function of path distances to the soma in microns
@@ -1466,7 +1504,9 @@ class Neuron:
                 maxDist = length
             dist.append(length)
             q.extend(i2)
-        return np.histogram2d(dist, radii, bins=bins, range=[[0, maxDist], [0, maxRadii]])
+        return np.histogram2d(
+            dist, radii, bins=bins, range=[[0, maxDist], [0, maxRadii]]
+        )
 
     @staticmethod
     def from_swc(fname, force_format=True):
@@ -1489,7 +1529,7 @@ class Neuron:
         with open(fname, "r") as f:
             for line in f:
                 line = line.strip()
-                if len(line) is 0:
+                if len(line) == 0:
                     continue
                 if line.startswith("#"):
                     metadata += line + "\n"
@@ -1575,7 +1615,7 @@ class Neuron:
         if True:
             for line in data:
                 line = line.strip()
-                if len(line) is 0:
+                if len(line) == 0:
                     continue
                 if line.startswith("#"):
                     metadata += line + "\n"
