@@ -101,8 +101,6 @@ class TracingPoint:
         :return: a matplotlib `Figure` object which has been rendered.
         """
         import matplotlib as mpl
-
-        mpl.use("Agg")
         import matplotlib.pyplot as plt
         from matplotlib import collections as mc
 
@@ -117,26 +115,24 @@ class TracingPoint:
                 (node.x, node.y, node.z, node.parent.x, node.parent.y, node.parent.z)
             )
 
-        # for ix,iy,iz,jx,jy,jz in segments:
-        #    ax.plot( [ix, jx], [iy, jy], color=color )
         lc = None
         if axis == "z":
             lc = mc.LineCollection(
                 [[(ix, iy), (jx, jy)] for ix, iy, iz, jx, jy, jz in segments],
                 color=color,
-                linewidths=linewidth
+                linewidths=linewidth,
             )
         elif axis == "x":
             lc = mc.LineCollection(
                 [[(iy, iz), (jy, jz)] for ix, iy, iz, jx, jy, jz in segments],
                 color=color,
-                linewidths=linewidth
+                linewidths=linewidth,
             )
         elif axis == "y":
             lc = mc.LineCollection(
                 [[(ix, iz), (jx, jz)] for ix, iy, iz, jx, jy, jz in segments],
                 color=color,
-                linewidths=linewidth
+                linewidths=linewidth,
             )
         ax.add_collection(lc)
         ax.autoscale()
@@ -185,12 +181,6 @@ class TracingPoint:
 
         return out
 
-    # def __copy__(self):
-    #    return self
-
-    # def __setattr__(self, name, value):
-    #    self.__dict__[name] = value
-
     def __iter__(self):
         return iter(self.children)
 
@@ -280,6 +270,10 @@ class TracingPoint:
             out.append(out[-1].parent)
         return out
 
+    def euclidean_dist_to_root(self):
+        root_path = self.get_path_to_root()
+        return self.euclidean_dist(root_path[-1])
+
     def path_dist_to_root(self):
         """
         :note: Uses result from :func:`get_path_to_root`
@@ -482,18 +476,18 @@ class TracingPoint:
 
         Example:
             >>> neuron = from_swc("Example1.swc")
-            >>> dq = get_tip_nodes(neuron)
+            >>> dq = neuron.get_tip_nodes()
             >>> dq[0]
             TracingPoint(x=-3.0, y=3.0, z=1.5, r=1.0, t=3, parent=TracingPoint(x=-2.0, y=2.0, z=1.0, r=1.0, t=3, children=[{ 2, truncated }], parent={...}))
-            >>> neurite_tortuosity(dq[0])
+            >>> dq[0].neurite_tortuosity()
             0.04134791479135339
         """
         t = self
-        pathLength = 0
+        pathLength = 0.0
         while t.parent:
             pathLength += t.euclidean_dist(t.parent)
             t = t.parent
-        euclideanStartToEnd = euclidean_dist(t, self)
+        euclideanStartToEnd = self.euclidean_dist(t)
         return math.log10(pathLength / euclideanStartToEnd)
 
     def angle(self, a, b):
@@ -527,8 +521,8 @@ class TracingPoint:
             >>> ba.angle(p1, p2)
             109.47122063449069
         """
-        ax, ay, az = a.x - branchPoint.x, a.y - branchPoint.y, a.z - branchPoint.z
-        bx, by, bz = b.x - branchPoint.x, b.y - branchPoint.y, b.z - branchPoint.z
+        ax, ay, az = a.x - self.x, a.y - self.y, a.z - self.z
+        bx, by, bz = b.x - self.x, b.y - self.y, b.z - self.z
         magA = (ax ** 2 + ay ** 2 + az ** 2) ** 0.5
         magB = (bx ** 2 + by ** 2 + bz ** 2) ** 0.5
         if magA == 0 or magB == 0:
@@ -538,7 +532,7 @@ class TracingPoint:
         rad = dotProduct / (magA * magB)
         rad = min(rad, 1)
         rad = max(rad, -1)
-        return m.acos(rad) * (180 / math.pi)
+        return math.acos(rad) * (180 / math.pi)
 
     '''def sackin_index(self):
         """
@@ -552,21 +546,6 @@ class TracingPoint:
             out += sum(1 for i in tip.get_path_to_root() if i.is_bif())
         return out / n'''
 
-    '''
-    def colless_index(self):
-        """
-        Calculates the Sackin index of a given branch
-
-        See: https://journals.plos.org/plosone/article?id=10.1371/journal.pone.0224197"""
-        out, l = 0.0, len(self.get_tip_nodes())
-        n = ((2.483) ** (l)) * ((l) ** (-3.0 / 2.0))
-        for bif in self.get_bifurcation_nodes():
-            out += abs(
-                bif.children[0].total_tip_nodes() - bif.children[1].total_tip_nodes()
-            )
-        return (2.0 * out) / ((n - 1) * (n - 2))
-    '''
-
     @staticmethod
     def slice_surface_area(points):
         """
@@ -618,11 +597,6 @@ class TracingPoint:
         memory = {None: -1}  # track line numbers of each element
         out = []
 
-        # tail = self.farthest_tip()
-        #        while tail is not self:
-        # todo.appendleft( tail )
-        #           tail = tail.parent
-
         while todo:
             a = todo.pop()
             if a in memory:  # duplicate
