@@ -2,11 +2,13 @@
 nGauge
 
 A python library for neuron morphology.
+
+https://github.com/Cai-Lab-at-University-of-Michigan/nGauge
 """
 
-__version__ = "0.1.4"
+__version__ = "1.0.0"
 __author__ = (
-    "Logan A Walker <loganaw@umich.edu> and Jennifer Willams <jenwill@umich.edu>"
+    "Logan A Walker <loganaw@umich.edu> and Jennifer S Willams <jenwill@umich.edu>"
 )
 __credits__ = "The University of Michigan"
 
